.. PSyclone Reference Guide documentation master file, created by
   sphinx-quickstart on Wed May 15 11:51:32 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PSyclone Reference Guide
########################

Welcome to the PSyclone Reference Guide. This consists of auto-generated
API documentation produced using both the :ref:`AutoAPI Sphinx plugin <autoapi>`
and :ref:`Doxygen <doxygen>`.

.. _autoapi:

Sphinx and AutoAPI-generated Documentation
==========================================

.. toctree::
   :hidden:
   
   autogenerated/psyclone

The Sphinx/AutoAPI documentation is
:doc:`here. <autogenerated/psyclone>` or you can use the navigation
pane on the left.

.. _doxygen:

Doxygen-generated Documentation
===============================

.. raw:: html

   <p>
   If you would prefer to see the Doxgen-generated pages then they are 
   <a  href="_static/html/index.html">here.</a> Since these are generated
   separately there are no links back to this Sphinx-generated content - you
   will need to use the back button on your browser.
   <p>

